@@ -17,6 +17,7 @@ import files_sdk.models.bandwidth_snapshot as bandwidth_snapshot
 import files_sdk.models.behavior as behavior
 import files_sdk.models.bundle as bundle
 import files_sdk.models.bundle_download as bundle_download
+import files_sdk.models.bundle_notification as bundle_notification
 import files_sdk.models.bundle_recipient as bundle_recipient
 import files_sdk.models.bundle_registration as bundle_registration
 import files_sdk.models.clickwrap as clickwrap
@@ -60,6 +61,7 @@ import files_sdk.models.public_ip_address as public_ip_address
 import files_sdk.models.public_key as public_key
 import files_sdk.models.remote_bandwidth_snapshot as remote_bandwidth_snapshot
 import files_sdk.models.remote_server as remote_server
+import files_sdk.models.remote_server_configuration_file as remote_server_configuration_file
 import files_sdk.models.request as request
 import files_sdk.models.session as session
 import files_sdk.models.settings_change as settings_change
@@ -93,6 +95,7 @@ from files_sdk.models.bandwidth_snapshot import BandwidthSnapshot
 from files_sdk.models.behavior import Behavior
 from files_sdk.models.bundle import Bundle
 from files_sdk.models.bundle_download import BundleDownload
+from files_sdk.models.bundle_notification import BundleNotification
 from files_sdk.models.bundle_recipient import BundleRecipient
 from files_sdk.models.bundle_registration import BundleRegistration
 from files_sdk.models.clickwrap import Clickwrap
@@ -136,6 +139,7 @@ from files_sdk.models.public_ip_address import PublicIpAddress
 from files_sdk.models.public_key import PublicKey
 from files_sdk.models.remote_bandwidth_snapshot import RemoteBandwidthSnapshot
 from files_sdk.models.remote_server import RemoteServer
+from files_sdk.models.remote_server_configuration_file import RemoteServerConfigurationFile
 from files_sdk.models.request import Request
 from files_sdk.models.session import Session
 from files_sdk.models.settings_change import SettingsChange
