@@ -15,8 +15,6 @@ class BandwidthSnapshot:
         'requests_put': None,     # double - Site bandwidth report put requests
         'requests_other': None,     # double - Site bandwidth report other requests
         'logged_at': None,     # date-time - Time the site bandwidth report was logged
-        'created_at': None,     # date-time - Site bandwidth report created at date/time
-        'updated_at': None,     # date-time - The last time this site bandwidth report was updated
     }
 
     def __init__(self, attributes=None, options=None):
@@ -36,9 +34,9 @@ class BandwidthSnapshot:
 
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
+#   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `logged_at`.
+#   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction (e.g. `sort_by[logged_at]=desc`). Valid fields are `logged_at`.
 #   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `logged_at`.
 #   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `logged_at`.
 #   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `logged_at`.
