@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
@@ -8,10 +9,13 @@ class PaymentLineItem:
         'created_at': None,     # date-time - Payment line item created at date/time
         'invoice_id': None,     # int64 - Invoice ID
         'payment_id': None,     # int64 - Payment ID
-        'updated_at': None,     # date-time - Payment line item updated at date/time
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
