@@ -53,6 +53,8 @@ class RemoteServer:
         'files_agent_permission_set': None,     # string - Local permissions for files agent. read_only, write_only, or read_write
         'files_agent_root': None,     # string - Agent local root path
         'files_agent_api_token': None,     # string - Files Agent API Token
+        'filebase_bucket': None,     # string - Filebase Bucket name
+        'filebase_access_key': None,     # string - Filebase Access Key.
         'aws_secret_key': None,     # string - AWS secret key.
         'password': None,     # string - Password if needed.
         'private_key': None,     # string - Private key if needed.
@@ -67,6 +69,7 @@ class RemoteServer:
         'azure_blob_storage_access_key': None,     # string - Azure Blob Storage secret key.
         'azure_files_storage_access_key': None,     # string - Azure File Storage access key.
         's3_compatible_secret_key': None,     # string - S3-compatible secret key
+        'filebase_secret_key': None,     # string - Filebase secret key
     }
 
     def __init__(self, attributes=None, options=None):
@@ -97,6 +100,7 @@ class RemoteServer:
     #   private_key - string - private key
     #   public_key - string - public key
     #   server_host_key - string
+    #   subdomain - string
     def configuration_file(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -129,6 +133,8 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: public_key must be an str")
         if "server_host_key" in params and not isinstance(params["server_host_key"], str):
             raise InvalidParameterError("Bad parameter: server_host_key must be an str")
+        if "subdomain" in params and not isinstance(params["subdomain"], str):
+            raise InvalidParameterError("Bad parameter: subdomain must be an str")
         response, _options = Api.send_request("POST", "/remote_servers/{id}/configuration_file".format(id=params['id']), params, self.options)
         return response.data
 
@@ -184,6 +190,9 @@ class RemoteServer:
     #   s3_compatible_secret_key - string - S3-compatible secret key
     #   files_agent_root - string - Agent local root path
     #   files_agent_permission_set - string - Local permissions for files agent. read_only, write_only, or read_write
+    #   filebase_access_key - string - Filebase Access Key.
+    #   filebase_secret_key - string - Filebase secret key
+    #   filebase_bucket - string - Filebase Bucket name
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -292,6 +301,12 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: files_agent_root must be an str")
         if "files_agent_permission_set" in params and not isinstance(params["files_agent_permission_set"], str):
             raise InvalidParameterError("Bad parameter: files_agent_permission_set must be an str")
+        if "filebase_access_key" in params and not isinstance(params["filebase_access_key"], str):
+            raise InvalidParameterError("Bad parameter: filebase_access_key must be an str")
+        if "filebase_secret_key" in params and not isinstance(params["filebase_secret_key"], str):
+            raise InvalidParameterError("Bad parameter: filebase_secret_key must be an str")
+        if "filebase_bucket" in params and not isinstance(params["filebase_bucket"], str):
+            raise InvalidParameterError("Bad parameter: filebase_bucket must be an str")
         response, _options = Api.send_request("PATCH", "/remote_servers/{id}".format(id=params['id']), params, self.options)
         return response.data
 
@@ -321,7 +336,7 @@ class RemoteServer:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
+#   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 def list(params = None, options = None):
     if not isinstance(params, dict):
@@ -422,6 +437,9 @@ def find_configuration_file(id, params = None, options = None):
 #   s3_compatible_secret_key - string - S3-compatible secret key
 #   files_agent_root - string - Agent local root path
 #   files_agent_permission_set - string - Local permissions for files agent. read_only, write_only, or read_write
+#   filebase_access_key - string - Filebase Access Key.
+#   filebase_secret_key - string - Filebase secret key
+#   filebase_bucket - string - Filebase Bucket name
 def create(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -523,6 +541,12 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: files_agent_root must be an str")
     if "files_agent_permission_set" in params and not isinstance(params["files_agent_permission_set"], str):
         raise InvalidParameterError("Bad parameter: files_agent_permission_set must be an str")
+    if "filebase_access_key" in params and not isinstance(params["filebase_access_key"], str):
+        raise InvalidParameterError("Bad parameter: filebase_access_key must be an str")
+    if "filebase_secret_key" in params and not isinstance(params["filebase_secret_key"], str):
+        raise InvalidParameterError("Bad parameter: filebase_secret_key must be an str")
+    if "filebase_bucket" in params and not isinstance(params["filebase_bucket"], str):
+        raise InvalidParameterError("Bad parameter: filebase_bucket must be an str")
     response, options = Api.send_request("POST", "/remote_servers", params, options)
     return RemoteServer(response.data, options)
 
@@ -539,6 +563,7 @@ def create(params = None, options = None):
 #   private_key - string - private key
 #   public_key - string - public key
 #   server_host_key - string
+#   subdomain - string
 def configuration_file(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -567,6 +592,8 @@ def configuration_file(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: public_key must be an str")
     if "server_host_key" in params and not isinstance(params["server_host_key"], str):
         raise InvalidParameterError("Bad parameter: server_host_key must be an str")
+    if "subdomain" in params and not isinstance(params["subdomain"], str):
+        raise InvalidParameterError("Bad parameter: subdomain must be an str")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     response, options = Api.send_request("POST", "/remote_servers/{id}/configuration_file".format(id=params['id']), params, options)
@@ -624,6 +651,9 @@ def configuration_file(id, params = None, options = None):
 #   s3_compatible_secret_key - string - S3-compatible secret key
 #   files_agent_root - string - Agent local root path
 #   files_agent_permission_set - string - Local permissions for files agent. read_only, write_only, or read_write
+#   filebase_access_key - string - Filebase Access Key.
+#   filebase_secret_key - string - Filebase secret key
+#   filebase_bucket - string - Filebase Bucket name
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -728,6 +758,12 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: files_agent_root must be an str")
     if "files_agent_permission_set" in params and not isinstance(params["files_agent_permission_set"], str):
         raise InvalidParameterError("Bad parameter: files_agent_permission_set must be an str")
+    if "filebase_access_key" in params and not isinstance(params["filebase_access_key"], str):
+        raise InvalidParameterError("Bad parameter: filebase_access_key must be an str")
+    if "filebase_secret_key" in params and not isinstance(params["filebase_secret_key"], str):
+        raise InvalidParameterError("Bad parameter: filebase_secret_key must be an str")
+    if "filebase_bucket" in params and not isinstance(params["filebase_bucket"], str):
+        raise InvalidParameterError("Bad parameter: filebase_bucket must be an str")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     response, options = Api.send_request("PATCH", "/remote_servers/{id}".format(id=params['id']), params, options)
