@@ -26,6 +26,7 @@ class Site:
         'bundle_upload_receipt_notifications': None,     # string - Do Bundle uploaders receive upload confirmation notifications?
         'bundle_watermark_attachment': None,     # Image - Preview watermark image applied to all bundle items.
         'bundle_watermark_value': None,     # object - Preview watermark settings applied to all bundle items. Uses the same keys as Behavior.value
+        'uploads_via_email_authentication': None,     # boolean - Do incoming emails in the Inboxes require checking for SPF/DKIM/DMARC?
         'color2_left': None,     # string - Page link and button color
         'color2_link': None,     # string - Top bar link color
         'color2_text': None,     # string - Page link and button color
@@ -299,6 +300,7 @@ def get_usage(params = None, options = None):
 #   ldap_group_exclusion - string - Comma or newline separated list of group names (with optional wildcards) to exclude when syncing.
 #   ldap_group_inclusion - string - Comma or newline separated list of group names (with optional wildcards) to include when syncing.
 #   ldap_base_dn - string - Base DN for looking up users in LDAP server
+#   uploads_via_email_authentication - boolean - Do incoming emails in the Inboxes require checking for SPF/DKIM/DMARC?
 #   icon16_file - file
 #   icon16_delete - boolean - If true, will delete the file stored in icon16
 #   icon32_file - file
